<?php
namespace Ari_Fancy_Lightbox\Views\Settings;

use Ari_Fancy_Lightbox\Views\Base as Base;
use Ari\Controls\Tabs\Tabs as Tabs;

class Html extends Base {
    public $tabs;

    public function display( $tmpl = null ) {
        $this->set_title( __( 'ARI Fancy Lightbox - Settings', 'ari-fancy-lightbox' ) );

        wp_enqueue_style( 'ari-qtip' );

        $this->init_tabs();

        parent::display( $tmpl );
    }

    protected function groups_output( $groups ) {
        $data = $this->get_data();
        $form = $data['form'];
        $output = '';

        foreach ( $groups as $key => $val ) {
            $options = array();
            $group = $val;
            if ( is_array( $val ) ) {
                $group = $key;
                $options = $val;
            }

            $output .= $form->output( $group, $options );
        }

        return $output;
    }

    public function init_tabs() {
        $tabs = new Tabs(
            'afl_settings_tabs',

            array(
                'items' => array(
                    array(
                        'id' => 'integration',

                        'title' => __( 'Integration', 'ari-fancy-lightbox' ),

                        'content' => function() {
                            $groups = array(
                                'wp_gallery',

                                'wp_gallery_config',

                                'images',

                                'youtube',

                                'vimeo',

                                'metacafe',

                                'dailymotion',

                                'vine',

                                'instagram',

                                'google_maps',

                                'links',
                            );

                            return $this->groups_output( $groups );
                        },
                    ),

                    array(
                        'id' => 'lightbox',

                        'title' => __( 'Lightbox', 'ari-fancy-lightbox' ),

                        'content' => function() {
                            $groups = array(
                                'lightbox',

                                'lightbox_buttons',
                            );

                            return $this->groups_output( $groups );
                        },
                    ),

                    array(
                        'id' => 'style',

                        'title' => __( 'Style', 'ari-fancy-lightbox' ),

                        'content' => function() {
                            $groups = array(
                                'style',
                            );

                            return $this->groups_output( $groups );
                        },
                    ),

                    array(
                        'id' => 'advanced',

                        'title' => __( 'Advanced', 'ari-fancy-lightbox' ),

                        'content' => function() {
                            $groups = array(
                                'advanced',
                            );

                            return $this->groups_output( $groups );
                        },
                    ),

                    array(
                        'id' => 'upgrade',

                        'title' => __( 'Upgrade', 'ari-fancy-lightbox'),

                        'content' => function() {
                            return '<p>Like the plugin, but need more features? <a href="http://wp-quiz.ari-soft.com/plugins/wordpress-fancy-lightbox.html#pricing" target="_blank">Upgrade to PRO</a> version:
                                <ul class="ari-features">
                                    <li><strong>Deeplinking</strong> creates unique links for lightbox items. Possible to open the lightbox by a deeplink.</li>
                                    <li><strong>Social networks integration</strong> share content via popular social networks: Facebook, Twitter, Google+, Pinterest, LinkedIn, VKontakte.</li>
                                    <li><strong>Disable the lightbox on small screens</strong>.</li>
                                    <li><strong>Show popup on page load automatically</strong>.</li>
                                    <li>and other awesome features.</li>
                                </ul>
                                <h4>Want upgrade to PRO for <strong>free</strong>? Just <a href="mailto:info@ari-soft.com?subject=' . rawurlencode( 'REQUEST: Free upgrade to "ARI Fancy Lightbox PRO"' ) . '">contact us</a> and know how to do it.</h4>
                            </p>';
                        }
                    )
                )
            )
        );

        $this->tabs = $tabs;
    }
}
